aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--langs/report_tx_git.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/langs/report_tx_git.php b/langs/report_tx_git.php
index 23a3c2811..7628f3db9 100644
--- a/langs/report_tx_git.php
+++ b/langs/report_tx_git.php
@@ -583,7 +583,7 @@ foreach ($tx_resources_info as $tx_resource_info) {
// it seems like a parse error
if (0 == $git_resource_num_of_all_strings) {
$parse_errors[$git_resource_name][] = $git_resource_language;
// this bellow should normaly only happen inside of a tx sync window so remember it
} else if ($tx_resource_all_strings_in_lang != $git_resource_num_of_all_strings) {
if (!array_key_exists($git_resource_name, $nonequal_num_of_all_strings)) {
$nonequal_num_text = "$git_resource_name git:$git_resource_num_of_all_strings/tx:$tx_resource_all_strings_in_lang";
@@ -660,7 +660,7 @@ if (0 < count($tx_only_languages)) {
// preparing error texts
if (0 < count($git_only_languages)) {
$error = "Note that some languages (" . implode(", ", $git_only_languages) . ") are present in our git";
- $errors['git_only_languages'] = "$error but they are bellow treshold ($tx_lang_completed_treshold %) in Transifex.";
+ $errors['git_only_languages'] = "$error but they are below treshold ($tx_lang_completed_treshold %) in Transifex.";
}
if (0 < count($tx_only_resources)) {
@@ -876,13 +876,13 @@ $diff_desc = "between Transifex and our git repository for $resource_type.";
if (0 < $num_of_resources_w_difference) {
// print any differences between Transifex and our git repository
if (!is_null($wanted_resource) && !is_null($wanted_language)) {
- $diff_title = "<h3>Language $wanted_lang_name bellow have some differences in resource $wanted_resource $diff_desc</h3>";
+ $diff_title = "<h3>Language $wanted_lang_name below have some differences in resource $wanted_resource $diff_desc</h3>";
} else if (!is_null($wanted_resource) && is_null($wanted_language)) {
- $diff_title = "<h3>Languages bellow have some differences in resource $wanted_resource $diff_desc</h3>";
+ $diff_title = "<h3>Languages below have some differences in resource $wanted_resource $diff_desc</h3>";
} else if (is_null($wanted_resource) && !is_null($wanted_language)) {
- $diff_title = "<h3>Language $wanted_lang_name bellow have some differences $diff_desc</h3>";
+ $diff_title = "<h3>Language $wanted_lang_name below have some differences $diff_desc</h3>";
} else {
- $diff_title = "<h3>Languages bellow have some differences in resources $diff_desc</h3>";
+ $diff_title = "<h3>Languages below have some differences in resources $diff_desc</h3>";
}
echo $diff_title;
echo '<p>To avoid further alienation and confusion please synchronise them.</p>';
@@ -583,7 +583,7 @@ foreach ($tx_resources_info as $tx_resource_info) {
if (0 == $git_resource_num_of_all_strings) {
$parse_errors[$git_resource_name][] = $git_resource_language;
- // this bellow should normaly only happen inside of a tx sync window so remember it
+ // this below should normaly only happen inside of a tx sync window so remember it
} else if ($tx_resource_all_strings_in_lang != $git_resource_num_of_all_strings) {
if (!array_key_exists($git_resource_name, $nonequal_num_of_all_strings)) {